pub fn correct_offset(
filtered_offset: usize,
corrections: &[OffsetCorrection],
) -> usizeExpand description
Map a byte offset in filtered text back to the original text.
pub fn correct_offset(
filtered_offset: usize,
corrections: &[OffsetCorrection],
) -> usizeMap a byte offset in filtered text back to the original text.