pub enum RankingExpression {
Fusion {
sources: Vec<QueryExpression>,
method: FusionMethod,
rank_constant: f32,
rank_window_size: Option<usize>,
weights: Option<Vec<f32>>,
},
}Expand description
Result-set composition expressions.
See [[feature-rrf-retrievers#RankingExpression]].
Variants
Fusion
Fuse N query sources using a configurable method.
Each source is executed independently, then results are combined using the specified fusion method. Sources can be scoring queries or nested fusion expressions.
Fields

sources: Vec<QueryExpression>
method: FusionMethodTrait Implementations
Sourceimpl Clone for RankingExpression
impl Clone for RankingExpression
Sourcefn clone(&self) -> RankingExpression
fn clone(&self) -> RankingExpression
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RankingExpression
impl Debug for RankingExpression
Sourceimpl PartialEq for RankingExpression
impl PartialEq for RankingExpression
Sourcefn eq(&self, other: &RankingExpression) -> bool
fn eq(&self, other: &RankingExpression) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for RankingExpression