Function score query: modify query scores using scoring functions.
Wraps an inner query and applies one or more scoring functions (weight, field_value_factor, random_score) to modify the final score.
See [[elasticsearch-parity]].
Function score query: modify query scores using scoring functions.
Wraps an inner query and applies one or more scoring functions (weight, field_value_factor, random_score) to modify the final score.
See [[elasticsearch-parity]].