Module reader

Module reader 

IndexReader: open committed index, provide search snapshots.

Reads all committed segments from storage and creates a Searcher snapshot for querying.

See [[architecture-query-execution]] and [[architecture-overview#Step 10]].

Structs

IndexReader
Opens an index for reading by loading all committed segments.