pub struct ParsedGraph {
pub params: HnswParams,
pub num_vectors: usize,
pub entry_point: Option<u32>,
pub max_level: usize,
pub vector_data_offset: usize,
pub quantized_offset: Option<usize>,
pub quantized_len: usize,
/* private fields */
}Expand description
Parsed graph structure (nodes + neighbors). This is the only part that needs heap allocation. Cached in SegmentReader.
Fields
params: HnswParamsnum_vectors: usizeentry_point: Option<u32>max_level: usizevector_data_offset: usizeByte offset where vector data starts in the segment slice.
quantized_offset: Option<usize>Byte offset where quantized data starts (if present).
quantized_len: usizeLength of quantized data block.
Implementations